@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Ivan Vasić                                      *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.           *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Ivan Vasić <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "bwschedulerplugin.h"
 
 #include <QDateTime>
@@ -87,7 +72,7 @@ void BWSchedulerPlugin::load()
         m_schedule->clear();
     }
 
-    m_editor = new ScheduleEditor(0);
+    m_editor = new ScheduleEditor(nullptr);
     connect(m_editor, &ScheduleEditor::loaded, this, &BWSchedulerPlugin::onLoaded);
     connect(m_editor, &ScheduleEditor::scheduleChanged, this, &BWSchedulerPlugin::timerTriggered);
     getGUI()->addActivity(m_editor);
